drempel v0.1.4 Drempel View Source

API and GenServer for the backoff handling.

Link to this section Summary

Functions

Returns a specification to start this module under a supervisor

Looks up the term key from a term bucket

Returns the remaining delay associated with key in bucket. If bucket doesn't contain key, returns default (or 0 if not provided)

Invoked when the server is started. start_link/3 or start/3 will block until it returns

Adds a hit to the term key in a given term bucket

Starts the Server

Returns the remaining delay associated with key in bucket. If the delay is 0 adds a hit to the term key in a given term bucket. If bucket doesn't contain key, returns default (or 0 if not provided)

Link to this section Functions

Returns a specification to start this module under a supervisor.

See Supervisor.

Looks up the term key from a term bucket.

Returns {:ok, delay} if the key exists in the bucket, :error otherwise.

Link to this function

get(bucket, key, default \\ 0) View Source

Returns the remaining delay associated with key in bucket. If bucket doesn't contain key, returns default (or 0 if not provided).

Invoked when the server is started. start_link/3 or start/3 will block until it returns.

init_arg is the argument term (second argument) passed to start_link/3.

Returning {:ok, state} will cause start_link/3 to return {:ok, pid} and the process to enter its loop.

Returning {:ok, state, timeout} is similar to {:ok, state} except handle_info(:timeout, state) will be called after timeout milliseconds if no messages are received within the timeout.

Returning {:ok, state, :hibernate} is similar to {:ok, state} except the process is hibernated before entering the loop. See c:handle_call/3 for more information on hibernation.

Returning {:ok, state, {:continue, continue}} is similar to {:ok, state} except that immediately after entering the loop the c:handle_continue/2 callback will be invoked with the value continue as first argument.

Returning :ignore will cause start_link/3 to return :ignore and the process will exit normally without entering the loop or calling c:terminate/2. If used when part of a supervision tree the parent supervisor will not fail to start nor immediately try to restart the GenServer. The remainder of the supervision tree will be started and so the GenServer should not be required by other processes. It can be started later with Supervisor.restart_child/2 as the child specification is saved in the parent supervisor. The main use cases for this are:

  • The GenServer is disabled by configuration but might be enabled later.
  • An error occurred and it will be handled by a different mechanism than the Supervisor. Likely this approach involves calling Supervisor.restart_child/2 after a delay to attempt a restart.

Returning {:stop, reason} will cause start_link/3 to return {:error, reason} and the process to exit with reason reason without entering the loop or calling c:terminate/2.

Callback implementation for GenServer.init/1.

Adds a hit to the term key in a given term bucket.

Starts the Server.

Link to this function

update(bucket, key, default \\ 0) View Source

Returns the remaining delay associated with key in bucket. If the delay is 0 adds a hit to the term key in a given term bucket. If bucket doesn't contain key, returns default (or 0 if not provided).